==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/vi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Trình hướng dẫn chạy lần đầu",
    "Add your profile information! For example your email is needed to receive notifications." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo và đặt lại mật khẩu của bạn.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ và tên đầy đủ để dễ nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt tên đầy đủ để dễ dàng nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ để nhận dạng dễ dàng hơn trên tất cả các tính năng.",
    "Schedule work & meetings, synced with all your devices." : "Lên lịch làm việc và cuộc họp, đồng bộ hóa với tất cả các thiết bị của bạn.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Giữ đồng nghiệp và bạn bè của bạn ở một nơi mà không làm rò rỉ thông tin cá nhân của họ.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Ứng dụng email đơn giản được tích hợp độc đáo với Tệp, Danh bạ và Lịch.",
    "App recommendation: Tasks" : "Đề xuất ứng dụng: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Đồng bộ hóa các tác vụ từ nhiều thiết bị khác nhau với Cloud của bạn và chỉnh sửa chúng trực tuyến.",
    "App recommendation: Deck" : "Đề xuất ứng dụng: Deck",
    "Kanban style organization for personal planning and team projects." : "Tổ chức theo phong cách Kanban để lập kế hoạch cá nhân và dự án nhóm",
    "App recommendation: Forms" : "Đề xuất ứng dụng: Biểu mẫu",
    "Simple surveys and questionnaires, self-hosted" : "Các khảo sát và bảng câu hỏi đơn giản, tự lưu trữ",
    "App recommendation: Recognize" : "Đề xuất ứng dụng: Nhận biết",
    "Smart media tagging for Nextcloud" : "Gắn thẻ phương tiện thông minh",
    "App recommendation: Group folders" : "Đề xuất ứng dụng: Nhóm thư mục",
    "Admin-configured folders shared by everyone in a group." : "Các thư mục do quản trị viên định cấu hình được chia sẻ bởi mọi người trong nhóm.",
    "Connect your calendar" : "Kết nối lịch của bạn",
    "Connect your contacts" : "Kết nối danh bạ của bạn",
    "Access files via WebDAV" : "Truy cập file qua WebDAV",
    "Download macOS/iOS configuration profile" : "Tải xuống hồ sơ cấu hình macOS/iOS",
    "Desktop client" : "Máy khách để bàn",
    "iOS app" : "Ứng dụng IOS",
    "A welcome and introduction wizard for Nextcloud" : "Trình hướng dẫn chào mừng và giới thiệu",
    "Close" : "Đóng",
    "Welcome to {cloudName}!" : "Chào mừng đến với {cloudName}!",
    "Privacy" : "Bảo mật",
    "Community" : "Cộng đồng",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Server address" : "Địa chỉ máy chủ",
    "Use this link to connect your apps and desktop client to this server:" : "Sử dụng liên kết này để kết nối ứng dụng và máy khách để bàn của bạn với máy chủ này:",
    "Read more" : "Đọc thêm",
    "App recommendation: Nextcloud Calendar" : "Đề xuất ứng dụng: Lịch",
    "App recommendation: Nextcloud Contacts" : "Đề xuất ứng dụng: Danh bạ",
    "App recommendation: Nextcloud Mail" : "Đề xuất ứng dụng: Mail"
},
"nplurals=1; plural=0;");

==> nextcloud-32.0.6-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/vi.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Trình hướng dẫn chạy lần đầu",
    "Add your profile information! For example your email is needed to receive notifications." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo.",
    "Add your profile information! For example your email is needed to receive notifications and reset your password." : "Thêm thông tin hồ sơ của bạn! Ví dụ: email của bạn là cần thiết để nhận thông báo và đặt lại mật khẩu của bạn.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ và tên đầy đủ để dễ nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt tên đầy đủ để dễ dàng nhận biết hơn trên tất cả các tính năng.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Thêm thông tin hồ sơ của bạn! Đặt ảnh hồ sơ để nhận dạng dễ dàng hơn trên tất cả các tính năng.",
    "Schedule work & meetings, synced with all your devices." : "Lên lịch làm việc và cuộc họp, đồng bộ hóa với tất cả các thiết bị của bạn.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Giữ đồng nghiệp và bạn bè của bạn ở một nơi mà không làm rò rỉ thông tin cá nhân của họ.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Ứng dụng email đơn giản được tích hợp độc đáo với Tệp, Danh bạ và Lịch.",
    "App recommendation: Tasks" : "Đề xuất ứng dụng: Tasks",
    "Sync tasks from various devices with your Nextcloud and edit them online." : "Đồng bộ hóa các tác vụ từ nhiều thiết bị khác nhau với Cloud của bạn và chỉnh sửa chúng trực tuyến.",
    "App recommendation: Deck" : "Đề xuất ứng dụng: Deck",
    "Kanban style organization for personal planning and team projects." : "Tổ chức theo phong cách Kanban để lập kế hoạch cá nhân và dự án nhóm",
    "App recommendation: Forms" : "Đề xuất ứng dụng: Biểu mẫu",
    "Simple surveys and questionnaires, self-hosted" : "Các khảo sát và bảng câu hỏi đơn giản, tự lưu trữ",
    "App recommendation: Recognize" : "Đề xuất ứng dụng: Nhận biết",
    "Smart media tagging for Nextcloud" : "Gắn thẻ phương tiện thông minh",
    "App recommendation: Group folders" : "Đề xuất ứng dụng: Nhóm thư mục",
    "Admin-configured folders shared by everyone in a group." : "Các thư mục do quản trị viên định cấu hình được chia sẻ bởi mọi người trong nhóm.",
    "Connect your calendar" : "Kết nối lịch của bạn",
    "Connect your contacts" : "Kết nối danh bạ của bạn",
    "Access files via WebDAV" : "Truy cập file qua WebDAV",
    "Download macOS/iOS configuration profile" : "Tải xuống hồ sơ cấu hình macOS/iOS",
    "Desktop client" : "Máy khách để bàn",
    "iOS app" : "Ứng dụng IOS",
    "A welcome and introduction wizard for Nextcloud" : "Trình hướng dẫn chào mừng và giới thiệu",
    "Close" : "Đóng",
    "Welcome to {cloudName}!" : "Chào mừng đến với {cloudName}!",
    "Skip" : "Bỏ qua",
    "Privacy" : "Bảo mật",
    "Community" : "Cộng đồng",
    "Get the apps to sync your files" : "Nhận ứng dụng để đồng bộ file của bạn",
    "Server address" : "Địa chỉ máy chủ",
    "Use this link to connect your apps and desktop client to this server:" : "Sử dụng liên kết này để kết nối ứng dụng và máy khách để bàn của bạn với máy chủ này:",
    "Read more" : "Đọc thêm"
},
"nplurals=1; plural=0;");
